@@ -1,11 +1,7 @@
 package HTTP::Throwable::Role::Status::Found;
-BEGIN {
-  $HTTP::Throwable::Role::Status::Found::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $HTTP::Throwable::Role::Status::Found::VERSION = '0.018';
-}
-use Moose::Role;
+our $AUTHORITY = 'cpan:STEVAN';
+$HTTP::Throwable::Role::Status::Found::VERSION = '0.024';
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -16,17 +12,19 @@ with(
 sub default_status_code { 302 }
 sub default_reason      { 'Found' }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTTP::Throwable::Role::Status::Found - 302 Found
 
 =head1 VERSION
 
-version 0.018
+version 0.024
 
 =head1 DESCRIPTION
 
@@ -75,3 +73,21 @@ __END__
 
 # ABSTRACT: 302 Found
 
+#pod =head1 DESCRIPTION
+#pod
+#pod The requested resource resides temporarily under a different URI.
+#pod Since the redirection might be altered on occasion, the client
+#pod SHOULD continue to use the Request-URI for future requests. This
+#pod response is only cacheable if indicated by a Cache-Control or
+#pod Expires header field.
+#pod
+#pod The temporary URI SHOULD be given by the Location field in the
+#pod response. Unless the request method was HEAD, the entity of the
+#pod response SHOULD contain a short hypertext note with a hyperlink
+#pod to the new URI(s).
+#pod
+#pod =attr location
+#pod
+#pod This is a required string, which will be used in the Location header
+#pod when creating a PSGI response.
+#pod
