@@ -1,11 +1,7 @@
 package HTTP::Throwable::Role::Status::GatewayTimeout;
-BEGIN {
-  $HTTP::Throwable::Role::Status::GatewayTimeout::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $HTTP::Throwable::Role::Status::GatewayTimeout::VERSION = '0.018';
-}
-use Moose::Role;
+our $AUTHORITY = 'cpan:STEVAN';
+$HTTP::Throwable::Role::Status::GatewayTimeout::VERSION = '0.024';
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -15,17 +11,19 @@ with(
 sub default_status_code { 504 }
 sub default_reason      { 'Gateway Timeout' }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTTP::Throwable::Role::Status::GatewayTimeout - 504 Gateway Timeout
 
 =head1 VERSION
 
-version 0.018
+version 0.024
 
 =head1 DESCRIPTION
 
@@ -62,3 +60,11 @@ __END__
 
 # ABSTRACT: 504 Gateway Timeout
 
+#pod =head1 DESCRIPTION
+#pod
+#pod The server, while acting as a gateway or proxy, did not
+#pod receive a timely response from the upstream server specified
+#pod by the URI (e.g. HTTP, FTP, LDAP) or some other auxiliary
+#pod server (e.g. DNS) it needed to access in attempting to
+#pod complete the request.
+#pod
