@@ -1,11 +1,7 @@
 package HTTP::Throwable::Role::Status::HTTPVersionNotSupported;
-BEGIN {
-  $HTTP::Throwable::Role::Status::HTTPVersionNotSupported::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $HTTP::Throwable::Role::Status::HTTPVersionNotSupported::VERSION = '0.017';
-}
-use Moose::Role;
+our $AUTHORITY = 'cpan:STEVAN';
+$HTTP::Throwable::Role::Status::HTTPVersionNotSupported::VERSION = '0.024';
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -15,17 +11,19 @@ with(
 sub default_status_code { 505 }
 sub default_reason      { 'HTTP Version Not Supported' }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTTP::Throwable::Role::Status::HTTPVersionNotSupported - 505 HTTP Version Not Supported
 
 =head1 VERSION
 
-version 0.017
+version 0.024
 
 =head1 DESCRIPTION
 
@@ -65,3 +63,13 @@ __END__
 
 # ABSTRACT: 505 HTTP Version Not Supported
 
+#pod =head1 DESCRIPTION
+#pod
+#pod The server does not support, or refuses to support, the
+#pod HTTP protocol version that was used in the request message.
+#pod The server is indicating that it is unable or unwilling to
+#pod complete the request using the same major version as the
+#pod client, other than with this error message. The response
+#pod SHOULD contain an entity describing why that version is not
+#pod supported and what other protocols are supported by that
+#pod server.
